@@ -7,45 +7,20 @@ Python 3.8+
 Author: niftycode
 Modified by: thecircleisround
 Date created: October 8th, 2020
-Date modified: September 17th, 2021
+Date modified: February 19th, 2022
 """
 
 import sys
-from dataclasses import dataclass
+
 from os.path import expanduser
 
-from imessage_reader import common, create_sqlite, write_excel
-
-
-@dataclass
-class MessageData:
-    """
-    This dataclass is the store for the data:
-    user id (sender), text, date, service and account (destination caller id).
-    """
-    user_id: str
-    text: str
-    date: str
-    service: str
-    account: str
-    is_from_me: int
-
-    def __str__(self):
-        """
-        :return: String representation of this object
-        """
-        return f"sender (user id): {self.user_id}:\n" \
-               f"message: {self.text}\n" \
-               f"date: {self.date}\n" \
-               f"service: {self.service}\n" \
-               f"destination caller id: {self.account}\n "\
-               f"is_from_me: {self.is_from_me}\n"
+from imessage_reader import common, create_sqlite, write_excel, data_container
 
 
 # noinspection PyMethodMayBeStatic
 class FetchData:
     """
-    This class contains the methods for fetch, print and export the messages.
+    This class contains the methods to fetch, print and export the messages.
     """
 
     # The path to the iMessage database
@@ -80,13 +55,13 @@ class FetchData:
 
         data = []
         for row in rval:
-            data.append(MessageData(row[2], row[0], row[1], row[3], row[4], row[5]))
+            data.append(data_container.MessageData(row[2], row[0], row[1], row[3], row[4], row[5]))
 
         return data
 
     def show_user_txt(self, export: str):
         """
-        Call fetch_message_data() method, print fetched data and export data.
+        Invoke _read_database(), print fetched data and export data.
         This method is for CLI usage.
         :param export: Determine whether to export data
         """
@@ -112,7 +87,7 @@ class FetchData:
     def _export_excel(self, data: list):
         """
         Export data (write Excel file)
-        :param data: imessage objects containing user id, message, date, service, account
+        :param data: message objects containing user id, message, date, service, account
         """
         file_path = expanduser("~") + '/Desktop/'
         ew = write_excel.ExelWriter(data, file_path)
@@ -121,7 +96,7 @@ class FetchData:
     def _export_sqlite(self, data: list):
         """
         Export data (create SQLite3 database)
-        :param data: imessage objects containig user id, message, date, service, account
+        :param data: message objects containig user id, message, date, service, account
         """
         file_path = expanduser("~") + '/Desktop/'
         cd = create_sqlite.CreateDatabase(data, file_path)
@@ -142,7 +117,6 @@ class FetchData:
         account = []
         is_from_me = []
 
-
         for data in fetched_data:
             users.append(data.user_id)
             messages.append(data.text)
@@ -154,3 +128,20 @@ class FetchData:
         data = list(zip(users, messages, dates, service, account, is_from_me))
 
         return data
+
+    def get_recipients(self) -> list:
+        """
+        Create a list containing all recipients
+        This method is for module usage.
+        :return: List with recipients
+        """
+        fetched_data = self._read_database()
+
+        recipients = []
+
+        for data in fetched_data:
+            # Check if a message is from me
+            if data.is_from_me == 0:
+                recipients.append(data.user_id)
+
+        return recipients
